@@ -16,6 +16,7 @@ def test_notset():
 
 
 def test_popattr():
+
     class Foo:
         a = 1
         bb = 2
@@ -34,5 +35,5 @@ def test_exclusive_setitem():
     assert dct['foo'] == 1
     with pytest.raises(KeyError):
         utils.exclusive_setitem(dct, 'foo', 1)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='already in dictionary'):
         utils.exclusive_setitem(dct, 'foo', 1, ValueError)
